@@ -111,6 +111,13 @@ class SendGrid(object):
     def list_identity(self, name=None):
         return self.call('identity', 'list', {"name": name} if name else {})
 
+    def add_identity(self, **fields):
+        '''Fields required are: city, state, zip, address, country, name, email, identity'''
+        return self.call('identity', 'add', dict(**fields))
+
+    def get_identity(self, identity):
+        return self.call('identity', 'get', {"identity": identity})
+
     def add_list(self, name):
         return self.call('lists', 'add', {"list": name})
 
